@@ -1,5 +1,7 @@
 #! /usr/bin/python
-import rowingdata
+from __future__ import absolute_import
+from __future__ import print_function
+from . import rowingdata
 from sys import argv
 
 readFile=argv[1]
@@ -20,8 +22,8 @@ row=rowingdata.rowingdata(outfile,rowtype="Indoor Rower",rower=rower)
 
 row.plottime_erg()
 
-print(row.allstats())
+print((row.allstats()))
 
 
 
-print("done "+readFile)
+print(("done "+readFile))
